@@ -3,9 +3,9 @@
 import warthog.exceptions
 
 
-class TestWarthogError(object):
+class TestWarthogApiError(object):
     def test_str(self):
-        err = warthog.exceptions.WarthogError('Oh no!', api_msg='Something bad', api_code=1234)
+        err = warthog.exceptions.WarthogApiError('Oh no!', api_msg='Something bad', api_code=1234)
         str_err = str(err)
 
         assert 'Oh no!' in str_err, 'Did not see expected message in error'
@@ -13,8 +13,8 @@ class TestWarthogError(object):
         assert '1234' in str_err, 'Did not see expected API code in error'
 
     def test_repr(self):
-        err = warthog.exceptions.WarthogError('Oh no!', api_msg='Something bad', api_code=1234)
+        err = warthog.exceptions.WarthogApiError('Oh no!', api_msg='Something bad', api_code=1234)
         repr_err = repr(err)
 
-        assert 'WarthogError("Oh no!", api_msg="Something bad", api_code=1234)' == repr_err, \
+        assert 'WarthogApiError("Oh no!", api_msg="Something bad", api_code=1234)' == repr_err, \
             'Did not get expected repr of exception'
\ No newline at end of file
